pub struct DevKeyProvider { /* private fields */ }Expand description
Simple development key provider that uses deterministic material to wrap DEKs.
Implementations
Sourceimpl DevKeyProvider
impl DevKeyProvider
Sourcepub fn from_material(input: &[u8]) -> Self
pub fn from_material(input: &[u8]) -> Self
Construct the provider by hashing arbitrary input into a fixed-size key.